"""
Terminal to grapheme mapping of overrides, using a hash registry.

This code generated by python wcwidth using ucs-detect project data.
"""
# pylint: skip-file
_REGISTRY = {
    'alacritty': '45d92e98',
    'apple_terminal': 'e08bd75e',
    'bobcat': '970dbe10',
    'contour': 'fd9d4c44',
    'extraterm': 'fcc05a0f',
    'foot': '529fbb4a',
    'ghostty': '4cdf59ce',
    'iterm2': '8589765c',
    'kitty': 'c0a2cdbf',
    'konsole': 'c2157f7e',
    'mintty': '3d4826b8',
    'mlterm': 'c3db41c0',
    'pterm': '5bfac390',
    'rio': '8f94b404',
    'st': '813fee16',
    'terminology': 'e22030f3',
    'urxvt': '813fee16',
    'vte': '5bfac390',
    'warp': '27e0693f',
    'wezterm': 'da9ceb0a',
    'xterm': '813fee16',
    'xterm.js': '50bf0759',
}

__all__ = ('_REGISTRY',)
