"""
Exports VS15_WIDE_TO_NARROW table keyed by supporting unicode version level.

This code generated by python wcwidth project.
"""
# pylint: disable=duplicate-code
VS15_WIDE_TO_NARROW = {
    '9.0.0': (
        # Source: 9.0.0
        # Date: 2025-01-30, 21:48:29 GMT
        #
        (0x0231a, 0x0231b,),  # Watch                   ..Hourglass
        (0x023e9, 0x023ec,),  # Black Right-pointing Dou..Black Down-pointing Doub
        (0x023f0, 0x023f0,),  # Alarm Clock
        (0x023f3, 0x023f3,),  # Hourglass With Flowing Sand
        (0x025fd, 0x025fe,),  # White Medium Small Squar..Black Medium Small Squar
        (0x02614, 0x02615,),  # Umbrella With Rain Drops..Hot Beverage
        (0x02648, 0x02653,),  # Aries                   ..Pisces
        (0x0267f, 0x0267f,),  # Wheelchair Symbol
        (0x02693, 0x02693,),  # Anchor
        (0x026a1, 0x026a1,),  # High Voltage Sign
        (0x026aa, 0x026ab,),  # Medium White Circle     ..Medium Black Circle
        (0x026bd, 0x026be,),  # Soccer Ball             ..Baseball
        (0x026c4, 0x026c5,),  # Snowman Without Snow    ..Sun Behind Cloud
        (0x026ce, 0x026ce,),  # Ophiuchus
        (0x026d4, 0x026d4,),  # No Entry
        (0x026ea, 0x026ea,),  # Church
        (0x026f2, 0x026f3,),  # Fountain                ..Flag In Hole
        (0x026f5, 0x026f5,),  # Sailboat
        (0x026fa, 0x026fa,),  # Tent
        (0x026fd, 0x026fd,),  # Fuel Pump
        (0x02705, 0x02705,),  # White Heavy Check Mark
        (0x0270a, 0x0270b,),  # Raised Fist             ..Raised Hand
        (0x02728, 0x02728,),  # Sparkles
        (0x0274c, 0x0274c,),  # Cross Mark
        (0x0274e, 0x0274e,),  # Negative Squared Cross Mark
        (0x02753, 0x02755,),  # Black Question Mark Orna..White Exclamation Mark O
        (0x02757, 0x02757,),  # Heavy Exclamation Mark Symbol
        (0x02795, 0x02797,),  # Heavy Plus Sign         ..Heavy Division Sign
        (0x027b0, 0x027b0,),  # Curly Loop
        (0x027bf, 0x027bf,),  # Double Curly Loop
        (0x02b1b, 0x02b1c,),  # Black Large Square      ..White Large Square
        (0x02b50, 0x02b50,),  # White Medium Star
        (0x02b55, 0x02b55,),  # Heavy Large Circle
        (0x03030, 0x03030,),  # Wavy Dash
        (0x0303d, 0x0303d,),  # Part Alternation Mark
        (0x03297, 0x03297,),  # Circled Ideograph Congratulation
        (0x03299, 0x03299,),  # Circled Ideograph Secret
        (0x1f004, 0x1f004,),  # Mahjong Tile Red Dragon
        (0x1f202, 0x1f202,),  # Squared Katakana Sa
        (0x1f21a, 0x1f21a,),  # Squared Cjk Unified Ideograph-7121
        (0x1f22f, 0x1f22f,),  # Squared Cjk Unified Ideograph-6307
        (0x1f237, 0x1f237,),  # Squared Cjk Unified Ideograph-6708
        (0x1f30d, 0x1f30f,),  # Earth Globe Europe-afric..Earth Globe Asia-austral
        (0x1f315, 0x1f315,),  # Full Moon Symbol
        (0x1f31c, 0x1f31c,),  # Last Quarter Moon With Face
        (0x1f378, 0x1f378,),  # Cocktail Glass
        (0x1f393, 0x1f393,),  # Graduation Cap
        (0x1f3a7, 0x1f3a7,),  # Headphone
        (0x1f3ac, 0x1f3ae,),  # Clapper Board           ..Video Game
        (0x1f3c2, 0x1f3c2,),  # Snowboarder
        (0x1f3c4, 0x1f3c4,),  # Surfer
        (0x1f3c6, 0x1f3c6,),  # Trophy
        (0x1f3ca, 0x1f3ca,),  # Swimmer
        (0x1f3e0, 0x1f3e0,),  # House Building
        (0x1f3ed, 0x1f3ed,),  # Factory
        (0x1f408, 0x1f408,),  # Cat
        (0x1f415, 0x1f415,),  # Dog
        (0x1f41f, 0x1f41f,),  # Fish
        (0x1f426, 0x1f426,),  # Bird
        (0x1f442, 0x1f442,),  # Ear
        (0x1f446, 0x1f449,),  # White Up Pointing Backha..White Right Pointing Bac
        (0x1f44d, 0x1f44e,),  # Thumbs Up Sign          ..Thumbs Down Sign
        (0x1f453, 0x1f453,),  # Eyeglasses
        (0x1f46a, 0x1f46a,),  # Family
        (0x1f47d, 0x1f47d,),  # Extraterrestrial Alien
        (0x1f4a3, 0x1f4a3,),  # Bomb
        (0x1f4b0, 0x1f4b0,),  # Money Bag
        (0x1f4b3, 0x1f4b3,),  # Credit Card
        (0x1f4bb, 0x1f4bb,),  # Personal Computer
        (0x1f4bf, 0x1f4bf,),  # Optical Disc
        (0x1f4cb, 0x1f4cb,),  # Clipboard
        (0x1f4da, 0x1f4da,),  # Books
        (0x1f4df, 0x1f4df,),  # Pager
        (0x1f4e4, 0x1f4e6,),  # Outbox Tray             ..Package
        (0x1f4ea, 0x1f4ed,),  # Closed Mailbox With Lowe..Open Mailbox With Lowere
        (0x1f4f7, 0x1f4f7,),  # Camera
        (0x1f4f9, 0x1f4fb,),  # Video Camera            ..Radio
        (0x1f508, 0x1f508,),  # Speaker
        (0x1f50d, 0x1f50d,),  # Left-pointing Magnifying Glass
        (0x1f512, 0x1f513,),  # Lock                    ..Open Lock
        (0x1f550, 0x1f567,),  # Clock Face One Oclock   ..Clock Face Twelve-thirty
        (0x1f610, 0x1f610,),  # Neutral Face
        (0x1f687, 0x1f687,),  # Metro
        (0x1f68d, 0x1f68d,),  # Oncoming Bus
        (0x1f691, 0x1f691,),  # Ambulance
        (0x1f694, 0x1f694,),  # Oncoming Police Car
        (0x1f698, 0x1f698,),  # Oncoming Automobile
        (0x1f6ad, 0x1f6ad,),  # No Smoking Symbol
        (0x1f6b2, 0x1f6b2,),  # Bicycle
        (0x1f6b9, 0x1f6ba,),  # Mens Symbol             ..Womens Symbol
        (0x1f6bc, 0x1f6bc,),  # Baby Symbol
    ),
}
